@@ -2,7 +2,7 @@ rescale.sca <-
   function(x, mode="B", newscale=1, ...){
     # Rescales Weights of fit SCA nmodel
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: May 16, 2017
+    # last updated: May 25, 2018
     
     # check mode
     mode <- mode[1]
@@ -17,11 +17,13 @@ rescale.sca <-
     # check newscale
     nfac <- ncol(x$B)
     if(length(newscale)!=nfac) newscale <- rep(newscale[1],nfac)
+    if(any(newscale <= 0)) stop("Input 'newscale' must contain positive values.")
     
     # rescale factors
     if(mode=="B"){
       
       Bscale <- sqrt(colMeans(x$B^2))
+      if(any(Bscale == 0)) Bscale[Bscale == 0] <- 1
       svec <- newscale/Bscale
       if(nfac==1L) { Smat <- matrix(svec) } else { Smat <- diag(svec) }
       x$B <- x$B %*% Smat
@@ -33,6 +35,7 @@ rescale.sca <-
     } else {
       
       Cscale <- sqrt(colMeans(x$C^2))
+      if(any(Cscale == 0)) Cscale[Cscale == 0] <- 1
       svec <- newscale/Cscale
       if(nfac==1L) { Smat <- matrix(svec) } else { Smat <- diag(svec) }
       x$C <- x$C %*% Smat
