@@ -2,7 +2,7 @@ resign.sca <-
   function(x, mode="B", newsign=1, ...){
     # Resigns Weights of fit SCA nmodel
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: May 16, 2017
+    # last updated: May 25, 2018
     
     # check mode
     mode <- mode[1]
@@ -18,11 +18,13 @@ resign.sca <-
     nfac <- ncol(x$B)
     newsign <- sign(newsign)
     if(length(newsign)!=nfac) newsign <- rep(newsign[1],nfac)
+    if(any(newsign == 0)) stop("Input 'newsign' must contain entries of c(-1, 1).")
     
     # resign factors
     if(mode=="B"){
       
       Bsign <- sign(colMeans(x$B^3))
+      if(any(Bsign == 0)) Bsign[Bsign == 0] <- 1
       svec <- newsign*Bsign
       if(nfac==1L) { Smat <- matrix(svec) } else { Smat <- diag(svec) }
       x$B <- x$B %*% Smat
@@ -33,6 +35,7 @@ resign.sca <-
     } else {
       
       Csign <- sign(colMeans(x$C^3))
+      if(any(Csign == 0)) Csign[Csign == 0] <- 1
       svec <- newsign*Csign
       if(nfac==1L) { Smat <- matrix(svec) } else { Smat <- diag(svec) }
       x$C <- x$C %*% Smat
